package com.koydummu;


import java.util.regex.Matcher;
import java.util.regex.Pattern;

import android.app.AlertDialog;
import android.app.Application;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.apigee.sdk.data.client.entities.User;
import com.apigee.sdk.data.client.response.ApiResponse;

public class CreateUser extends BaseUserGridActivity implements OnClickListener {

	 EditText mUsername;
	   EditText mEmail;
	   EditText mPassword;
	   EditText mRepassword;
	   Button signup;

		ProgressDialog addAccountProgressDialog;
	   
		@Override
		protected void onCreate(Bundle savedInstanceState) 
		{
			super.onCreate(savedInstanceState);
			setContentView(R.layout.activity_create_user);
			
			mUsername = (EditText) findViewById(R.id.newusername);
			mEmail = (EditText) findViewById(R.id.newemail);
			mPassword = (EditText) findViewById(R.id.newpassword);
			mRepassword = (EditText) findViewById(R.id.repassword);
			signup = (Button) findViewById(R.id.sign_up);
			
			signup.setOnClickListener(new OnClickListener() {
				
				@Override
				public void onClick(View v) {
					// TODO Auto-generated method stub
					
					String kullaniciAdi = mUsername.getText().toString();
					String email = mEmail.getText().toString();
					String sifre = mPassword.getText().toString();
					String sifreTekrar = mRepassword.getText().toString();

					//if length of email < 6, show error
					if(email.length()<6){
						showAddAccountEmailLengthError();
						return;
					}

					//if email does not look like email show error
					Pattern pattern = Pattern.compile(".+@.+\\.[a-z]+");
					Matcher matcher = pattern.matcher(email);
					boolean matchFound = matcher.matches();
					if(!matchFound){
						showAddAccountEmailFormatError();
						return;
					}
					
					//if length password < 5, show error
					if(sifre.length()<5){
						showAddAccountPasswordLengthError();
						return;
					}
					
					if (! sifre.equals(sifreTekrar)) {
						showAddAccountPasswordError();
						return;
					}

					showAddAcctProgress();

					new AddAcctTask(myApp, kullaniciAdi, sifre, email).execute();
					
					ApiResponse apiResponse = usergridController.login(kullaniciAdi, sifre);
					User user = null;
					if (apiResponse != null) {
						user = apiResponse.getUser();
						System.out.println(user.getUsername());
					}
					
					if(user != null) {
						//show user profile
					}
					else {
						
					}
				}
			});
					
		}
		

		//show add account progress dialog
		public void showAddAcctProgress() {
			addAccountProgressDialog = ProgressDialog.show(this, "",
					"Kullanc yaratlyor. Ltfen bekleyin...", true);
			//Intent i = new Intent(CreateUser.this,Login.class);
			//startActivity(i);
		}
		
		//email length error
		private void showAddAccountEmailLengthError() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"Email must be six characters or more. Please try again.")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//password mismatch error
		private void showAddAccountPasswordError() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"Passwords don't match. Please try again.")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//password length error
		private void showAddAccountPasswordLengthError() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"Password must be five characters or more. Please try again.")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		
		//email length error
		private void showAddAccountEmailFormatError() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"Email format error. eg. ui@jquery.com")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//remove add account progress dialog
		public void hideAddAcctProgressDialog() {
			if (addAccountProgressDialog != null) {
				addAccountProgressDialog.dismiss();
			}
			addAccountProgressDialog = null;
		}

		//add account error dialog
		private void showAddAccountError() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"Unable to add account. Please try again.")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//client error dialog
		private void showAddAccountClientError(String error) {
			String message = "Error: " + error;
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(message)
			.setCancelable(false)
			.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int id) {
					dialog.dismiss();
				}
			});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//show account created dialog
		private void showAddAccountSuccess() {
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(
					"New account created.")
					.setCancelable(false)
					.setNeutralButton("Ok", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							Toast.makeText(getApplicationContext(), "profil gsteriliyor..",
									   Toast.LENGTH_LONG).show();
							
							
							Intent i = new Intent(CreateUser.this,Profile.class);
							i.putExtra("username",mUsername.getText().toString());
							startActivity(i);
							dialog.dismiss();
						}
					});
			AlertDialog alert = builder.create();
			alert.show();
		}
		
		//thread to try to add account
		private class AddAcctTask extends AsyncTask<Void, Void, ApiResponse> {

			Application app;
			String username;
			String password;
			String email;
			
			
			public AddAcctTask(Application app, String username, String password, String email) {
				this.app = app;
				this.username = username;
				this.password = password;
				this.email = email;
			}
			

			//main function, attempts to add account
			protected ApiResponse doInBackground(Void... v) {
				
				//attempt to post message
				return usergridController.addAccount(username, password, email);

			}

			
			//client responded, chech for errors, if none show success dialog
			protected void onPostExecute(ApiResponse response) {
				
				//hide progress dialog
				hideAddAcctProgressDialog();
				
				
				//if there is no response show error dialog
				if (response == null) {
					showAddAccountError();
					
					
			    //if there is a client error display it
				}else if(response.getError()!=null){
					showAddAccountClientError(response.getError().toString());
				}
		
				//Display successful creation dialog then return to login screen
				else{

					showAddAccountSuccess();

				}
			}

		}

		@Override
		public void onClick(View v) {
			// TODO Auto-generated method stub
			
		}
		
	}
